@@ -24,29 +24,29 @@ class Weibo:
         self.token = res['value']
 
     # Get the image url by pid and size.
-    def get(self, pid, size='large'):
+    def get(self, pid, size='large', format='jpg'):
         if size not in SIZES:
             size = 'large'
-        return PIC_HOST + size + '/' + pid
+        return PIC_HOST + size + '/' + pid + '.' + format
 
     # Get all kinds of image url by pid.
-    def getall(self, pid):
+    def getall(self, pid, format='jpg'):
         return {
-            'large': PIC_HOST + 'large/' + pid + '.jpg',
-            'bmiddle': PIC_HOST + 'bmiddle/' + pid + '.jpg',
-            'mw1024': PIC_HOST + 'mw1024/' + pid + '.jpg',
-            'mw690': PIC_HOST + 'mw690/' + pid + '.jpg',
-            'small': PIC_HOST + 'small/' + pid + '.jpg',
-            'square': PIC_HOST + 'square/' + pid + '.jpg',
-            'thumb180': PIC_HOST + 'thumb180/' + pid + '.jpg',
-            'thumbnail': PIC_HOST + 'thumbnail/' + pid + '.jpg',
+            'large': self.get(pid, 'large', format),
+            'bmiddle': self.get(pid, 'bmiddle', format),
+            'mw1024': self.get(pid, 'mw1024', format),
+            'mw690': self.get(pid, 'mw690', format),
+            'small': self.get(pid, 'small', format),
+            'square': self.get(pid, 'square', format),
+            'thumb180': self.get(pid, 'thumb180', format),
+            'thumbnail': self.get(pid, 'thumbnail', format),
         }
 
     # Upload image by url.
     def upload(self, **kwargs):
         source = kwargs.get('source')
         mode = kwargs.get('mode', 'file')
-        transparent = kwargs.get('transparent', False)
+        fmt = kwargs.get('format', False)
         debug = kwargs.get('debug', False)
         files = {'pic1': source, }
         if mode == 'file':
@@ -55,8 +55,7 @@ class Weibo:
         elif mode == 'base64':
             filep = source
             files = {'b64_data': filep}
-        mime = 'gif' if transparent else 'jpeg'
-        url = API_URL.format(mode, 'jpeg', mime)
+        url = API_URL.format(mode, 'jpeg', fmt)
         res = requests.post(url, files=files, headers=self.headers)
         html = res.text
 
@@ -65,21 +64,21 @@ class Weibo:
 
         target_str = re.findall(TARGET_RE, html)[0]
         json_data = json.loads(target_str)
-        picdata = json_data['pic_1']
-        pid = picdata.get('pid', None)
-        is_success = bool(pid) and picdata.get('width', 0) > 0
+        pdata = json_data['pic_1']
+        pid = pdata.get('pid', None)
+        is_success = bool(pid) and pdata.get('width', 0) > 0
 
         if is_success:
             return {
                 'success': True,
                 'pid': pid,
                 'url': self.get(pid),
-                **picdata
+                **pdata
             }
         else:
             return {
                 'success': False,
                 'pid': None,
                 'url': None,
-                **picdata
+                **pdata
             }
